ComponentDescriptor class

Constructors

ComponentDescriptor({required String name, required String description, required String category, required List<String> files, required List<ComponentDependency> dependencies, required Map<String, String> templates})
const

Properties

category String
final
dependencies List<ComponentDependency>
final
description String
final
files List<String>
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
templates Map<String, String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited