ProjectAnalyzer class

Constructors

ProjectAnalyzer(Directory root)

Properties

hashCode int
The hash code for this object.
no setterinherited
hasPubspec bool
no setter
isFlutterProject bool
no setter
pubspec File
no setter
root Directory
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveTargetDir({String fallback = 'lib/widgets'}) Directory
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited